Changes information about a Stage resource.
apigateway_update_stage(restApiId, stageName, patchOperations)[required] [Required] The string identifier of the associated RestApi.
[required] [Required] The name of the Stage resource to change information about.
A list of update operations to be applied to the specified resource and in the order specified in this list.
svc$update_stage(
restApiId = "string",
stageName = "string",
patchOperations = list(
list(
op = "add"|"remove"|"replace"|"move"|"copy"|"test",
path = "string",
value = "string",
from = "string"
)
)
)