View source: R/apigatewayv2_operations.R
| apigatewayv2_create_portal | R Documentation |
Creates a portal.
See https://www.paws-r-sdk.com/docs/apigatewayv2_create_portal/ for full documentation.
apigatewayv2_create_portal(
Authorization,
EndpointConfiguration,
IncludedPortalProductArns = NULL,
LogoUri = NULL,
PortalContent,
RumAppMonitorName = NULL,
Tags = NULL
)
Authorization |
[required] The authentication configuration for the portal. |
EndpointConfiguration |
[required] The domain configuration for the portal. Use a default domain provided by API Gateway or provide a fully-qualified domain name that you own. |
IncludedPortalProductArns |
The ARNs of the portal products included in the portal. |
LogoUri |
The URI for the portal logo image that is displayed in the portal header. |
PortalContent |
[required] The content of the portal. |
RumAppMonitorName |
The name of the Amazon CloudWatch RUM app monitor for the portal. |
Tags |
The collection of tags. Each tag element is associated with a given resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.