View source: R/apigatewayv2_operations.R
| apigatewayv2_create_portal_product | R Documentation |
Creates a new portal product.
See https://www.paws-r-sdk.com/docs/apigatewayv2_create_portal_product/ for full documentation.
apigatewayv2_create_portal_product(
Description = NULL,
DisplayName,
Tags = NULL
)
Description |
A description of the portal product. |
DisplayName |
[required] The name of the portal product as it appears in a published portal. |
Tags |
The collection of tags. Each tag element is associated with a given resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.