apigatewayv2_list_portals: Lists portals

View source: R/apigatewayv2_operations.R

apigatewayv2_list_portalsR Documentation

Lists portals

Description

Lists portals.

See https://www.paws-r-sdk.com/docs/apigatewayv2_list_portals/ for full documentation.

Usage

apigatewayv2_list_portals(MaxResults = NULL, NextToken = NULL)

Arguments

MaxResults

The maximum number of elements to be returned for this resource.

NextToken

The next page of elements from this collection. Not valid for the last element of the collection.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.