apigatewayv2_list_product_pages: Lists the product pages for a portal product

View source: R/apigatewayv2_operations.R

apigatewayv2_list_product_pagesR Documentation

Lists the product pages for a portal product

Description

Lists the product pages for a portal product.

See https://www.paws-r-sdk.com/docs/apigatewayv2_list_product_pages/ for full documentation.

Usage

apigatewayv2_list_product_pages(
  MaxResults = NULL,
  NextToken = NULL,
  PortalProductId,
  ResourceOwnerAccountId = NULL
)

Arguments

MaxResults

The maximum number of elements to be returned for this resource.

NextToken

The next page of elements from this collection. Not valid for the last element of the collection.

PortalProductId

[required] The portal product identifier.

ResourceOwnerAccountId

The account ID of the resource owner of the portal product.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.