apigatewayv2_list_routing_rules: Lists routing rules

View source: R/apigatewayv2_operations.R

apigatewayv2_list_routing_rulesR Documentation

Lists routing rules

Description

Lists routing rules.

See https://www.paws-r-sdk.com/docs/apigatewayv2_list_routing_rules/ for full documentation.

Usage

apigatewayv2_list_routing_rules(
  DomainName,
  DomainNameId = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

DomainName

[required] The domain name.

DomainNameId

The domain name ID.

MaxResults

The maximum number of elements to be returned for this resource.

NextToken

The next page of elements from this collection. Not valid for the last element of the collection.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.