View source: R/apigatewayv2_operations.R
| apigatewayv2_update_portal | R Documentation |
Updates a portal.
See https://www.paws-r-sdk.com/docs/apigatewayv2_update_portal/ for full documentation.
apigatewayv2_update_portal(
Authorization = NULL,
EndpointConfiguration = NULL,
IncludedPortalProductArns = NULL,
LogoUri = NULL,
PortalContent = NULL,
PortalId,
RumAppMonitorName = NULL
)
Authorization |
The authorization of the portal. |
EndpointConfiguration |
Represents an endpoint configuration. |
IncludedPortalProductArns |
The ARNs of the portal products included in the portal. |
LogoUri |
The logo URI. |
PortalContent |
Contains the content that is visible to portal consumers including the themes, display names, and description. |
PortalId |
[required] The portal identifier. |
RumAppMonitorName |
The CloudWatch RUM app monitor name. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.