View source: R/arczonalshift_operations.R
| arczonalshift_cancel_practice_run | R Documentation |
Cancel an in-progress practice run zonal shift in Amazon Application Recovery Controller.
See https://www.paws-r-sdk.com/docs/arczonalshift_cancel_practice_run/ for full documentation.
arczonalshift_cancel_practice_run(zonalShiftId)
zonalShiftId |
[required] The identifier of a practice run zonal shift in Amazon Application Recovery Controller that you want to cancel. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.