Returns a list of autoshifts for an Amazon Web Services Region. By default, the call returns only ACTIVE autoshifts. Optionally, you can specify the status parameter to return COMPLETED autoshifts.
See https://www.paws-r-sdk.com/docs/arczonalshift_list_autoshifts/ for full documentation.
arczonalshift_list_autoshifts(
maxResults = NULL,
nextToken = NULL,
status = NULL
)The number of objects that you want to return with this call.
Specifies that you want to receive the next page of results. Valid only
if you received a NextToken response in the previous request. If you
did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's NextToken response to
request the next page of results.
The status of the autoshift.