View source: R/arczonalshift_operations.R
| arczonalshift_start_practice_run | R Documentation |
Start an on-demand practice run zonal shift in Amazon Application Recovery Controller. With zonal autoshift enabled, you can start an on-demand practice run to verify preparedness at any time. Amazon Web Services also runs automated practice runs about weekly when you have enabled zonal autoshift.
See https://www.paws-r-sdk.com/docs/arczonalshift_start_practice_run/ for full documentation.
arczonalshift_start_practice_run(resourceIdentifier, awayFrom, comment)
resourceIdentifier |
[required] The identifier for the resource that you want to start a practice run zonal shift for. The identifier is the Amazon Resource Name (ARN) for the resource. |
awayFrom |
[required] The Availability Zone (for example, |
comment |
[required] The initial comment that you enter about the practice run. Be aware that this comment can be overwritten by Amazon Web Services if the automatic check for balanced capacity fails. For more information, see Capacity checks for practice runs in the Amazon Application Recovery Controller Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.