Update the status of autoshift observer notification. Autoshift observer notification enables you to be notified, through Amazon EventBridge, when there is an autoshift event for zonal autoshift.
See https://www.paws-r-sdk.com/docs/arczonalshift_update_autoshift_observer_notification_status/ for full documentation.
arczonalshift_update_autoshift_observer_notification_status(status)[required] The status to set for autoshift observer notification. If the status is
ENABLED, Route 53 ARC includes all autoshift events when you use the
Amazon EventBridge pattern Autoshift In Progress. When the status is
DISABLED, Route 53 ARC includes only autoshift events for autoshifts
when one or more of your resources is included in the autoshift.