View source: R/cloudfront_operations.R
| cloudfront_create_connection_group | R Documentation |
Creates a connection group.
See https://www.paws-r-sdk.com/docs/cloudfront_create_connection_group/ for full documentation.
cloudfront_create_connection_group(
Name,
Ipv6Enabled = NULL,
Tags = NULL,
AnycastIpListId = NULL,
Enabled = NULL
)
Name |
[required] The name of the connection group. Enter a friendly identifier that is unique within your Amazon Web Services account. This name can't be updated after you create the connection group. |
Ipv6Enabled |
Enable IPv6 for the connection group. The default is |
Tags |
A complex type that contains zero or more |
AnycastIpListId |
The ID of the Anycast static IP list. |
Enabled |
Enable the connection group. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.