View source: R/cloudfront_operations.R
| cloudfront_create_trust_store | R Documentation |
Creates a trust store.
See https://www.paws-r-sdk.com/docs/cloudfront_create_trust_store/ for full documentation.
cloudfront_create_trust_store(
Name,
CaCertificatesBundleSource,
UseClientCertificateOCSPEndpoint = NULL,
Tags = NULL
)
Name |
[required] A name for the trust store. |
CaCertificatesBundleSource |
[required] The CA certificates bundle source for the trust store. |
UseClientCertificateOCSPEndpoint |
A Boolean that determines whether to use the CA certificate's OCSP endpoint to check certificate revocation status. |
Tags |
A complex type that contains zero or more |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.