View source: R/cloudfront_operations.R
| cloudfront_get_connection_group_by_routing_endpoint | R Documentation |
Gets information about a connection group by using the endpoint that you specify.
See https://www.paws-r-sdk.com/docs/cloudfront_get_connection_group_by_routing_endpoint/ for full documentation.
cloudfront_get_connection_group_by_routing_endpoint(RoutingEndpoint)
RoutingEndpoint |
[required] The routing endpoint for the target connection group, such as d111111abcdef8.cloudfront.net. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.