cloudfront_get_distribution_tenant_by_domain: Gets information about a distribution tenant by the...

View source: R/cloudfront_operations.R

cloudfront_get_distribution_tenant_by_domainR Documentation

Gets information about a distribution tenant by the associated domain

Description

Gets information about a distribution tenant by the associated domain.

See https://www.paws-r-sdk.com/docs/cloudfront_get_distribution_tenant_by_domain/ for full documentation.

Usage

cloudfront_get_distribution_tenant_by_domain(Domain)

Arguments

Domain

[required] A domain name associated with the target distribution tenant.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.