View source: R/cloudfront_operations.R
| cloudfront_list_connection_functions | R Documentation |
Lists connection functions.
See https://www.paws-r-sdk.com/docs/cloudfront_list_connection_functions/ for full documentation.
cloudfront_list_connection_functions(
Marker = NULL,
MaxItems = NULL,
Stage = NULL
)
Marker |
Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field's value to the value of |
MaxItems |
The maximum number of connection functions that you want returned in the response. |
Stage |
The connection function's stage. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.