cloudfront_list_connection_groups: Lists the connection groups in your Amazon Web Services...

View source: R/cloudfront_operations.R

cloudfront_list_connection_groupsR Documentation

Lists the connection groups in your Amazon Web Services account

Description

Lists the connection groups in your Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/cloudfront_list_connection_groups/ for full documentation.

Usage

cloudfront_list_connection_groups(
  AssociationFilter = NULL,
  Marker = NULL,
  MaxItems = NULL
)

Arguments

AssociationFilter

Filter by associated Anycast IP list ID.

Marker

The marker for the next set of connection groups to retrieve.

MaxItems

The maximum number of connection groups to return.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.