cloudfront_list_distribution_tenants: Lists the distribution tenants in your Amazon Web Services...

View source: R/cloudfront_operations.R

cloudfront_list_distribution_tenantsR Documentation

Lists the distribution tenants in your Amazon Web Services account

Description

Lists the distribution tenants in your Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/cloudfront_list_distribution_tenants/ for full documentation.

Usage

cloudfront_list_distribution_tenants(
  AssociationFilter = NULL,
  Marker = NULL,
  MaxItems = NULL
)

Arguments

AssociationFilter

Filter by the associated distribution ID or connection group ID.

Marker

The marker for the next set of results.

MaxItems

The maximum number of distribution tenants to return.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.