View source: R/cloudfront_operations.R
| cloudfront_list_distribution_tenants_by_customization | R Documentation |
Lists distribution tenants by the customization that you specify.
See https://www.paws-r-sdk.com/docs/cloudfront_list_distribution_tenants_by_customization/ for full documentation.
cloudfront_list_distribution_tenants_by_customization(
WebACLArn = NULL,
CertificateArn = NULL,
Marker = NULL,
MaxItems = NULL
)
WebACLArn |
Filter by the ARN of the associated WAF web ACL. |
CertificateArn |
Filter by the ARN of the associated ACM certificate. |
Marker |
The marker for the next set of results. |
MaxItems |
The maximum number of distribution tenants to return by the specified customization. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.