View source: R/cloudfront_operations.R
| cloudfront_list_distributions_by_connection_function | R Documentation |
Lists distributions by connection function.
See https://www.paws-r-sdk.com/docs/cloudfront_list_distributions_by_connection_function/ for full documentation.
cloudfront_list_distributions_by_connection_function(
Marker = NULL,
MaxItems = NULL,
ConnectionFunctionIdentifier
)
Marker |
Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field's value to the value of |
MaxItems |
The maximum number of distributions that you want returned in the response. |
ConnectionFunctionIdentifier |
[required] The distributions by connection function identifier. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.