View source: R/cloudfront_operations.R
| cloudfront_list_distributions_by_connection_mode | R Documentation |
Lists the distributions by the connection mode that you specify.
See https://www.paws-r-sdk.com/docs/cloudfront_list_distributions_by_connection_mode/ for full documentation.
cloudfront_list_distributions_by_connection_mode(
Marker = NULL,
MaxItems = NULL,
ConnectionMode
)
Marker |
The marker for the next set of distributions to retrieve. |
MaxItems |
The maximum number of distributions to return. |
ConnectionMode |
[required] This field specifies whether the connection mode is through a standard distribution (direct) or a multi-tenant distribution with distribution tenants (tenant-only). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.