View source: R/cloudfront_operations.R
| cloudfront_list_distributions_by_owned_resource | R Documentation |
Lists the CloudFront distributions that are associated with the specified resource that you own.
See https://www.paws-r-sdk.com/docs/cloudfront_list_distributions_by_owned_resource/ for full documentation.
cloudfront_list_distributions_by_owned_resource(
ResourceArn,
Marker = NULL,
MaxItems = NULL
)
ResourceArn |
[required] The ARN of the CloudFront resource that you've shared with other Amazon Web Services accounts. |
Marker |
Use this field when paginating results to indicate where to begin in your list of distributions. The response includes distributions in the list that occur after the marker. To get the next page of the list, set this field's value to the value of |
MaxItems |
The maximum number of distributions to return. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.