cloudfront_list_domain_conflicts: We recommend that you use the ListDomainConflicts API...

View source: R/cloudfront_operations.R

cloudfront_list_domain_conflictsR Documentation

We recommend that you use the ListDomainConflicts API operation to check for domain conflicts, as it supports both standard distributions and distribution tenants

Description

We recommend that you use the list_domain_conflicts API operation to check for domain conflicts, as it supports both standard distributions and distribution tenants. list_conflicting_aliases performs similar checks but only supports standard distributions.

See https://www.paws-r-sdk.com/docs/cloudfront_list_domain_conflicts/ for full documentation.

Usage

cloudfront_list_domain_conflicts(
  Domain,
  DomainControlValidationResource,
  MaxItems = NULL,
  Marker = NULL
)

Arguments

Domain

[required] The domain to check for conflicts.

DomainControlValidationResource

[required] The distribution resource identifier. This can be the standard distribution or distribution tenant that has a valid certificate, which covers the domain that you specify.

MaxItems

The maximum number of domain conflicts to return.

Marker

The marker for the next set of domain conflicts.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.