View source: R/cloudfront_operations.R
| cloudfront_list_invalidations_for_distribution_tenant | R Documentation |
Lists the invalidations for a distribution tenant.
See https://www.paws-r-sdk.com/docs/cloudfront_list_invalidations_for_distribution_tenant/ for full documentation.
cloudfront_list_invalidations_for_distribution_tenant(
Id,
Marker = NULL,
MaxItems = NULL
)
Id |
[required] The ID of the distribution tenant. |
Marker |
Use this parameter when paginating results to indicate where to begin in your list of invalidation batches. Because the results are returned in decreasing order from most recent to oldest, the most recent results are on the first page, the second page will contain earlier results, and so on. To get the next page of results, set |
MaxItems |
The maximum number of invalidations to return for the distribution tenant. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.