cloudfront_list_trust_stores: Lists trust stores

View source: R/cloudfront_operations.R

cloudfront_list_trust_storesR Documentation

Lists trust stores

Description

Lists trust stores.

See https://www.paws-r-sdk.com/docs/cloudfront_list_trust_stores/ for full documentation.

Usage

cloudfront_list_trust_stores(Marker = NULL, MaxItems = NULL)

Arguments

Marker

Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

MaxItems

The maximum number of trust stores that you want returned in the response.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.