cloudfront_put_resource_policy: Creates a resource control policy for a given CloudFront...

View source: R/cloudfront_operations.R

cloudfront_put_resource_policyR Documentation

Creates a resource control policy for a given CloudFront resource

Description

Creates a resource control policy for a given CloudFront resource.

See https://www.paws-r-sdk.com/docs/cloudfront_put_resource_policy/ for full documentation.

Usage

cloudfront_put_resource_policy(ResourceArn, PolicyDocument)

Arguments

ResourceArn

[required] The Amazon Resource Name (ARN) of the CloudFront resource for which the policy is being created.

PolicyDocument

[required] The JSON-formatted resource policy to create.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.