View source: R/cloudfront_operations.R
| cloudfront_update_domain_association | R Documentation |
We recommend that you use the update_domain_association API operation to move a domain association, as it supports both standard distributions and distribution tenants. associate_alias performs similar checks but only supports standard distributions.
See https://www.paws-r-sdk.com/docs/cloudfront_update_domain_association/ for full documentation.
cloudfront_update_domain_association(Domain, TargetResource, IfMatch = NULL)
Domain |
[required] The domain to update. |
TargetResource |
[required] The target standard distribution or distribution tenant resource for the domain. You can specify either |
IfMatch |
The value of the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.