View source: R/cloudfront_operations.R
| cloudfront_verify_dns_configuration | R Documentation |
Verify the DNS configuration for your domain names. This API operation checks whether your domain name points to the correct routing endpoint of the connection group, such as d111111abcdef8.cloudfront.net. You can use this API operation to troubleshoot and resolve DNS configuration issues.
See https://www.paws-r-sdk.com/docs/cloudfront_verify_dns_configuration/ for full documentation.
cloudfront_verify_dns_configuration(Domain = NULL, Identifier)
Domain |
The domain name that you're verifying. |
Identifier |
[required] The identifier of the distribution tenant. You can specify the ARN, ID, or name of the distribution tenant. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.