View source: R/directconnect_operations.R
| directconnect_associate_connections_to_resiliency_group | R Documentation |
Associates one or more connections with the specified resiliency group. This operation is atomic: either all of the specified connections are associated, or the operation fails and no changes are made.
See https://www.paws-r-sdk.com/docs/directconnect_associate_connections_to_resiliency_group/ for full documentation.
directconnect_associate_connections_to_resiliency_group(
connectionIdentifiers,
resiliencyGroupId,
clientToken = NULL
)
connectionIdentifiers |
[required] The IDs or ARNs of the connections to associate with the resiliency group. |
resiliencyGroupId |
[required] The ID of the resiliency group. |
clientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.