directconnect_create_resiliency_group: Creates a resiliency group

View source: R/directconnect_operations.R

directconnect_create_resiliency_groupR Documentation

Creates a resiliency group

Description

Creates a resiliency group. A resiliency group lets you group Direct Connect connections together and manage them as a single unit to meet a target resiliency model.

See https://www.paws-r-sdk.com/docs/directconnect_create_resiliency_group/ for full documentation.

Usage

directconnect_create_resiliency_group(
  resiliencyGroupName,
  intendedResiliencyModel,
  clientToken = NULL,
  tags = NULL
)

Arguments

resiliencyGroupName

[required] The name of the resiliency group.

intendedResiliencyModel

[required] The resiliency model that the resiliency group is intended to meet. The valid values are maximum-resiliency, high-resiliency, and basic-resiliency.

clientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

tags

The tags to associate with the resiliency group.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.