directconnect_disassociate_connections_from_resiliency_group: Disassociates one or more connections from the specified...

View source: R/directconnect_operations.R

directconnect_disassociate_connections_from_resiliency_groupR Documentation

Disassociates one or more connections from the specified resiliency group

Description

Disassociates one or more connections from the specified resiliency group. This operation is atomic: either all of the specified connections are disassociated, or the operation fails and no changes are made.

See https://www.paws-r-sdk.com/docs/directconnect_disassociate_connections_from_resiliency_group/ for full documentation.

Usage

directconnect_disassociate_connections_from_resiliency_group(
  connectionIdentifiers,
  resiliencyGroupId,
  clientToken = NULL
)

Arguments

connectionIdentifiers

[required] The IDs or ARNs of the connections to disassociate from the resiliency group.

resiliencyGroupId

[required] The ID of the resiliency group.

clientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.