directconnect_list_resiliency_group_associations: Lists the connection associations for the specified...

View source: R/directconnect_operations.R

directconnect_list_resiliency_group_associationsR Documentation

Lists the connection associations for the specified resiliency group

Description

Lists the connection associations for the specified resiliency group.

See https://www.paws-r-sdk.com/docs/directconnect_list_resiliency_group_associations/ for full documentation.

Usage

directconnect_list_resiliency_group_associations(
  resiliencyGroupId,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

resiliencyGroupId

[required] The ID of the resiliency group.

maxResults

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

If MaxResults is given a value larger than 100, only 100 results are returned.

nextToken

The token for the next page of results.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.