directconnect_list_resiliency_groups: Lists the resiliency groups owned by your Amazon Web Services...

View source: R/directconnect_operations.R

directconnect_list_resiliency_groupsR Documentation

Lists the resiliency groups owned by your Amazon Web Services account in the current Amazon Web Services Region

Description

Lists the resiliency groups owned by your Amazon Web Services account in the current Amazon Web Services Region.

See https://www.paws-r-sdk.com/docs/directconnect_list_resiliency_groups/ for full documentation.

Usage

directconnect_list_resiliency_groups(maxResults = NULL, nextToken = NULL)

Arguments

maxResults

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

If MaxResults is given a value larger than 100, only 100 results are returned.

nextToken

The token for the next page of results.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.