directconnect_list_virtual_interface_routes: Lists the routes for the specified virtual interface

View source: R/directconnect_operations.R

directconnect_list_virtual_interface_routesR Documentation

Lists the routes for the specified virtual interface

Description

Lists the routes for the specified virtual interface.

See https://www.paws-r-sdk.com/docs/directconnect_list_virtual_interface_routes/ for full documentation.

Usage

directconnect_list_virtual_interface_routes(
  virtualInterfaceId = NULL,
  filters = NULL,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

virtualInterfaceId

The ID of the virtual interface.

filters

The filters to apply to the routes returned.

maxResults

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

If MaxResults is given a value larger than 100, only 100 results are returned.

nextToken

The token for the next page of results.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.