directconnect_update_connections_billing_mode: Updates the billing mode for the specified Direct Connect...

View source: R/directconnect_operations.R

directconnect_update_connections_billing_modeR Documentation

Updates the billing mode for the specified Direct Connect connections

Description

Updates the billing mode for the specified Direct Connect connections. You can update the billing mode for up to 200 connections in a single request.

See https://www.paws-r-sdk.com/docs/directconnect_update_connections_billing_mode/ for full documentation.

Usage

directconnect_update_connections_billing_mode(connectionIds, billingMode)

Arguments

connectionIds

[required] The IDs of the connections to update. You can specify from 1 to 200 connections.

billingMode

[required] The billing mode to apply to the specified connections. The valid values are PayAsYouGo, FlatRateTier1, FlatRateTier2, FlatRateTier3, FlatRateTier4, and FlatRateTier5.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.