Deregisters the specified instances from the specified load balancer. After the instance is deregistered, it no longer receives traffic from the load balancer.
See https://paws-r.github.io/docs/elb/deregister_instances_from_load_balancer.html for full documentation.
elb_deregister_instances_from_load_balancer(LoadBalancerName, Instances)[required] The name of the load balancer.
[required] The IDs of the instances.