powered by
Describes the tags associated with the specified load balancers.
elb_describe_tags(LoadBalancerNames)
[required] The names of the load balancers.
svc$describe_tags( LoadBalancerNames = list( "string" ) )
# NOT RUN { # This example describes the tags for the specified load balancer. # } # NOT RUN { svc$describe_tags( LoadBalancerNames = list( "my-load-balancer" ) ) # } # NOT RUN { # }
Run the code above in your browser using DataLab