Learn R Programming

paws.networking (version 0.2.0)

elb_register_instances_with_load_balancer: Adds the specified instances to the specified load balancer

Description

Adds the specified instances to the specified load balancer.

See https://paws-r.github.io/docs/elb/register_instances_with_load_balancer.html for full documentation.

Usage

elb_register_instances_with_load_balancer(LoadBalancerName, Instances)

Arguments

LoadBalancerName

[required] The name of the load balancer.

Instances

[required] The IDs of the instances.