Learn R Programming

paws.networking (version 0.2.0)

elbv2_register_targets: Registers the specified targets with the specified target group

Description

Registers the specified targets with the specified target group.

See https://paws-r.github.io/docs/elbv2/register_targets.html for full documentation.

Usage

elbv2_register_targets(TargetGroupArn, Targets)

Arguments

TargetGroupArn

[required] The Amazon Resource Name (ARN) of the target group.

Targets

[required] The targets.