View source: R/globalaccelerator_operations.R
| globalaccelerator_create_custom_routing_listener | R Documentation |
Create a listener to process inbound connections from clients to a custom routing accelerator. Connections arrive to assigned static IP addresses on the port range that you specify.
See https://www.paws-r-sdk.com/docs/globalaccelerator_create_custom_routing_listener/ for full documentation.
globalaccelerator_create_custom_routing_listener(
AcceleratorArn,
PortRanges,
IdempotencyToken
)
AcceleratorArn |
[required] The Amazon Resource Name (ARN) of the accelerator for a custom routing listener. |
PortRanges |
[required] The port range to support for connections from clients to your accelerator. Separately, you set port ranges for endpoints. For more information, see About endpoints for custom routing accelerators. |
IdempotencyToken |
[required] A unique, case-sensitive identifier that you provide to ensure the idempotency—that is, the uniqueness—of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.