networkfirewall_accep_netwo_firew_trans_gatew_attac: Accepts a transit gateway attachment request for Network...

networkfirewall_accept_network_firewall_transit_gateway_attachmentR Documentation

Accepts a transit gateway attachment request for Network Firewall

Description

Accepts a transit gateway attachment request for Network Firewall. When you accept the attachment request, Network Firewall creates the necessary routing components to enable traffic flow between the transit gateway and firewall endpoints.

See https://www.paws-r-sdk.com/docs/networkfirewall_accept_network_firewall_transit_gateway_attachment/ for full documentation.

Usage

networkfirewall_accept_network_firewall_transit_gateway_attachment(
  TransitGatewayAttachmentId
)

Arguments

TransitGatewayAttachmentId

[required] Required. The unique identifier of the transit gateway attachment to accept. This ID is returned in the response when creating a transit gateway-attached firewall.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.