networkfirewall_create_container_association: Creates a Network Firewall container association

View source: R/networkfirewall_operations.R

networkfirewall_create_container_associationR Documentation

Creates a Network Firewall container association

Description

Creates a Network Firewall container association. The association monitors container lifecycle events in your Amazon ECS or Amazon EKS clusters and resolves running container addresses for use in firewall rules.

See https://www.paws-r-sdk.com/docs/networkfirewall_create_container_association/ for full documentation.

Usage

networkfirewall_create_container_association(
  ContainerAssociationName,
  Description = NULL,
  Type,
  ContainerMonitoringConfigurations,
  Tags = NULL
)

Arguments

ContainerAssociationName

[required] The descriptive name of the container association. You can't change the name of a container association after you create it.

Description

A description of the container association.

Type

[required] The type of containers to monitor. You can't change the container type after creation. Valid values:

  • ECS - Amazon Elastic Container Service

  • EKS - Amazon Elastic Kubernetes Service

ContainerMonitoringConfigurations

[required] The monitoring configurations for the container association. Each configuration specifies an Amazon ECS or Amazon EKS cluster to monitor and optional attribute filters to narrow which containers are tracked.

Tags

The key:value pairs to associate with the resource.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.