View source: R/networkfirewall_operations.R
| networkfirewall_create_proxy | R Documentation |
Creates an Network Firewall Proxy
See https://www.paws-r-sdk.com/docs/networkfirewall_create_proxy/ for full documentation.
networkfirewall_create_proxy(
ProxyName,
NatGatewayId,
ProxyConfigurationName = NULL,
ProxyConfigurationArn = NULL,
ListenerProperties = NULL,
TlsInterceptProperties,
Tags = NULL
)
ProxyName |
[required] The descriptive name of the proxy. You can't change the name of a proxy after you create it. |
NatGatewayId |
[required] A unique identifier for the NAT gateway to use with proxy resources. |
ProxyConfigurationName |
The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it. You must specify the ARN or the name, and you can specify both. |
ProxyConfigurationArn |
The Amazon Resource Name (ARN) of a proxy configuration. You must specify the ARN or the name, and you can specify both. |
ListenerProperties |
Listener properties for HTTP and HTTPS traffic. |
TlsInterceptProperties |
[required] TLS decryption on traffic to filter on attributes in the HTTP header. |
Tags |
The key:value pairs to associate with the resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.