View source: R/networkfirewall_operations.R
| networkfirewall_create_proxy_configuration | R Documentation |
Creates an Network Firewall ProxyConfiguration
See https://www.paws-r-sdk.com/docs/networkfirewall_create_proxy_configuration/ for full documentation.
networkfirewall_create_proxy_configuration(
ProxyConfigurationName,
Description = NULL,
RuleGroupNames = NULL,
RuleGroupArns = NULL,
DefaultRulePhaseActions,
Tags = NULL
)
ProxyConfigurationName |
[required] The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it. |
Description |
A description of the proxy configuration. |
RuleGroupNames |
The proxy rule group name(s) to attach to the proxy configuration. You must specify the ARNs or the names, and you can specify both. |
RuleGroupArns |
The proxy rule group arn(s) to attach to the proxy configuration. You must specify the ARNs or the names, and you can specify both. |
DefaultRulePhaseActions |
[required] Evaluation points in the traffic flow where rules are applied. There are three phases in a traffic where the rule match is applied. |
Tags |
The key:value pairs to associate with the resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.