View source: R/networkfirewall_operations.R
| networkfirewall_create_proxy_rule_group | R Documentation |
Creates an Network Firewall ProxyRuleGroup
See https://www.paws-r-sdk.com/docs/networkfirewall_create_proxy_rule_group/ for full documentation.
networkfirewall_create_proxy_rule_group(
ProxyRuleGroupName,
Description = NULL,
Rules = NULL,
Tags = NULL
)
ProxyRuleGroupName |
[required] The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it. |
Description |
A description of the proxy rule group. |
Rules |
Individual rules that define match conditions and actions for application-layer traffic. Rules specify what to inspect (domains, headers, methods) and what action to take (allow, deny, alert). |
Tags |
The key:value pairs to associate with the resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.