View source: R/networkfirewall_operations.R
| networkfirewall_create_proxy_rules | R Documentation |
Creates Network Firewall ProxyRule resources.
See https://www.paws-r-sdk.com/docs/networkfirewall_create_proxy_rules/ for full documentation.
networkfirewall_create_proxy_rules(
ProxyRuleGroupArn = NULL,
ProxyRuleGroupName = NULL,
Rules
)
ProxyRuleGroupArn |
The Amazon Resource Name (ARN) of a proxy rule group. You must specify the ARN or the name, and you can specify both. |
ProxyRuleGroupName |
The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it. You must specify the ARN or the name, and you can specify both. |
Rules |
[required] Individual rules that define match conditions and actions for application-layer traffic. Rules specify what to inspect (domains, headers, methods) and what action to take (allow, deny, alert). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.