View source: R/networkfirewall_operations.R
| networkfirewall_create_vpc_endpoint_association | R Documentation |
Creates a firewall endpoint for an Network Firewall firewall. This type of firewall endpoint is independent of the firewall endpoints that you specify in the Firewall itself, and you define it in addition to those endpoints after the firewall has been created. You can define a VPC endpoint association using a different VPC than the one you used in the firewall specifications.
See https://www.paws-r-sdk.com/docs/networkfirewall_create_vpc_endpoint_association/ for full documentation.
networkfirewall_create_vpc_endpoint_association(
FirewallArn,
VpcId,
SubnetMapping,
Description = NULL,
Tags = NULL
)
FirewallArn |
[required] The Amazon Resource Name (ARN) of the firewall. |
VpcId |
[required] The unique identifier of the VPC where you want to create a firewall endpoint. |
SubnetMapping |
[required] The ID for a subnet that's used in an association with a firewall. This is used in |
Description |
A description of the VPC endpoint association. |
Tags |
The key:value pairs to associate with the resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.