| networkfirewall_delete_network_firewall_transit_gateway_attachment | R Documentation |
Deletes a transit gateway attachment from a Network Firewall. Either the firewall owner or the transit gateway owner can delete the attachment.
See https://www.paws-r-sdk.com/docs/networkfirewall_delete_network_firewall_transit_gateway_attachment/ for full documentation.
networkfirewall_delete_network_firewall_transit_gateway_attachment(
TransitGatewayAttachmentId
)
TransitGatewayAttachmentId |
[required] Required. The unique identifier of the transit gateway attachment to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.