networkfirewall_delete_container_association: Deletes a container association

View source: R/networkfirewall_operations.R

networkfirewall_delete_container_associationR Documentation

Deletes a container association

Description

Deletes a container association. The resource transitions to a DELETING state. Deletion is asynchronous - Network Firewall returns immediately while cleanup proceeds in the background. You can't delete a container association while a rule group references it.

See https://www.paws-r-sdk.com/docs/networkfirewall_delete_container_association/ for full documentation.

Usage

networkfirewall_delete_container_association(
  ContainerAssociationName = NULL,
  ContainerAssociationArn = NULL
)

Arguments

ContainerAssociationName

The descriptive name of the container association.

You must specify the ARN or the name, and you can specify both.

ContainerAssociationArn

The Amazon Resource Name (ARN) of the container association.

You must specify the ARN or the name, and you can specify both.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.