View source: R/networkfirewall_operations.R
| networkfirewall_delete_proxy | R Documentation |
Deletes the specified Proxy.
See https://www.paws-r-sdk.com/docs/networkfirewall_delete_proxy/ for full documentation.
networkfirewall_delete_proxy(NatGatewayId, ProxyName = NULL, ProxyArn = NULL)
NatGatewayId |
[required] The NAT Gateway the proxy is attached to. |
ProxyName |
The descriptive name of the proxy. You can't change the name of a proxy after you create it. You must specify the ARN or the name, and you can specify both. |
ProxyArn |
The Amazon Resource Name (ARN) of a proxy. You must specify the ARN or the name, and you can specify both. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.