View source: R/networkfirewall_operations.R
| networkfirewall_delete_proxy_rules | R Documentation |
Deletes the specified ProxyRule(s). currently attached to a ProxyRuleGroup
See https://www.paws-r-sdk.com/docs/networkfirewall_delete_proxy_rules/ for full documentation.
networkfirewall_delete_proxy_rules(
ProxyRuleGroupArn = NULL,
ProxyRuleGroupName = NULL,
Rules
)
ProxyRuleGroupArn |
The Amazon Resource Name (ARN) of a proxy rule group. You must specify the ARN or the name, and you can specify both. |
ProxyRuleGroupName |
The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it. You must specify the ARN or the name, and you can specify both. |
Rules |
[required] The proxy rule(s) to remove from the existing proxy rule group. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.