networkfirewall_describe_container_association: Retrieves the configuration and status of a container...

View source: R/networkfirewall_operations.R

networkfirewall_describe_container_associationR Documentation

Retrieves the configuration and status of a container association

Description

Retrieves the configuration and status of a container association.

See https://www.paws-r-sdk.com/docs/networkfirewall_describe_container_association/ for full documentation.

Usage

networkfirewall_describe_container_association(
  ContainerAssociationName = NULL,
  ContainerAssociationArn = NULL
)

Arguments

ContainerAssociationName

The descriptive name of the container association.

You must specify the ARN or the name, and you can specify both.

ContainerAssociationArn

The Amazon Resource Name (ARN) of the container association.

You must specify the ARN or the name, and you can specify both.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.