networkfirewall_describe_flow_operation: Returns key information about a specific flow operation

View source: R/networkfirewall_operations.R

networkfirewall_describe_flow_operationR Documentation

Returns key information about a specific flow operation

Description

Returns key information about a specific flow operation.

See https://www.paws-r-sdk.com/docs/networkfirewall_describe_flow_operation/ for full documentation.

Usage

networkfirewall_describe_flow_operation(
  FirewallArn,
  AvailabilityZone = NULL,
  VpcEndpointAssociationArn = NULL,
  VpcEndpointId = NULL,
  FlowOperationId
)

Arguments

FirewallArn

[required] The Amazon Resource Name (ARN) of the firewall.

AvailabilityZone

The ID of the Availability Zone where the firewall is located. For example, ⁠us-east-2a⁠.

Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation.

VpcEndpointAssociationArn

The Amazon Resource Name (ARN) of a VPC endpoint association.

VpcEndpointId

A unique identifier for the primary endpoint associated with a firewall.

FlowOperationId

[required] A unique identifier for the flow operation. This ID is returned in the responses to start and list commands. You provide to describe commands.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.