View source: R/networkfirewall_operations.R
| networkfirewall_describe_proxy_configuration | R Documentation |
Returns the data objects for the specified proxy configuration.
See https://www.paws-r-sdk.com/docs/networkfirewall_describe_proxy_configuration/ for full documentation.
networkfirewall_describe_proxy_configuration(
ProxyConfigurationName = NULL,
ProxyConfigurationArn = NULL
)
ProxyConfigurationName |
The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it. You must specify the ARN or the name, and you can specify both. |
ProxyConfigurationArn |
The Amazon Resource Name (ARN) of a proxy configuration. You must specify the ARN or the name, and you can specify both. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.