View source: R/networkfirewall_operations.R
| networkfirewall_describe_proxy_rule | R Documentation |
Returns the data objects for the specified proxy configuration for the specified proxy rule group.
See https://www.paws-r-sdk.com/docs/networkfirewall_describe_proxy_rule/ for full documentation.
networkfirewall_describe_proxy_rule(
ProxyRuleName,
ProxyRuleGroupName = NULL,
ProxyRuleGroupArn = NULL
)
ProxyRuleName |
[required] The descriptive name of the proxy rule. You can't change the name of a proxy rule after you create it. |
ProxyRuleGroupName |
The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it. You must specify the ARN or the name, and you can specify both. |
ProxyRuleGroupArn |
The Amazon Resource Name (ARN) of a proxy rule group. You must specify the ARN or the name, and you can specify both. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.