networkfirewall_describe_proxy_rule_group: Returns the data objects for the specified proxy rule group

View source: R/networkfirewall_operations.R

networkfirewall_describe_proxy_rule_groupR Documentation

Returns the data objects for the specified proxy rule group

Description

Returns the data objects for the specified proxy rule group.

See https://www.paws-r-sdk.com/docs/networkfirewall_describe_proxy_rule_group/ for full documentation.

Usage

networkfirewall_describe_proxy_rule_group(
  ProxyRuleGroupName = NULL,
  ProxyRuleGroupArn = NULL
)

Arguments

ProxyRuleGroupName

The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.

You must specify the ARN or the name, and you can specify both.

ProxyRuleGroupArn

The Amazon Resource Name (ARN) of a proxy rule group.

You must specify the ARN or the name, and you can specify both.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.