View source: R/networkfirewall_operations.R
| networkfirewall_describe_rule_group_summary | R Documentation |
Returns detailed information for a stateful rule group.
See https://www.paws-r-sdk.com/docs/networkfirewall_describe_rule_group_summary/ for full documentation.
networkfirewall_describe_rule_group_summary(
RuleGroupName = NULL,
RuleGroupArn = NULL,
Type = NULL
)
RuleGroupName |
The descriptive name of the rule group. You can't change the name of a rule group after you create it. You must specify the ARN or the name, and you can specify both. |
RuleGroupArn |
Required. The Amazon Resource Name (ARN) of the rule group. You must specify the ARN or the name, and you can specify both. |
Type |
The type of rule group you want a summary for. This is a required field. Valid value: Note that |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.