networkfirewall_list_container_associations: Lists the container associations in your account and Region

View source: R/networkfirewall_operations.R

networkfirewall_list_container_associationsR Documentation

Lists the container associations in your account and Region

Description

Lists the container associations in your account and Region. Use the NextToken parameter in subsequent requests to retrieve additional results.

See https://www.paws-r-sdk.com/docs/networkfirewall_list_container_associations/ for full documentation.

Usage

networkfirewall_list_container_associations(
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

MaxResults

The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a NextToken value that you can use in a subsequent call to get the next batch of objects.

NextToken

When you request a list of objects with a MaxResults setting, if the number of objects that are still available for retrieval exceeds the maximum you requested, Network Firewall returns a NextToken value in the response. To retrieve the next batch of objects, use the token returned from the prior request in your next request.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.