View source: R/networkfirewall_operations.R
| networkfirewall_list_flow_operation_results | R Documentation |
Returns the results of a specific flow operation.
See https://www.paws-r-sdk.com/docs/networkfirewall_list_flow_operation_results/ for full documentation.
networkfirewall_list_flow_operation_results(
FirewallArn,
FlowOperationId,
NextToken = NULL,
MaxResults = NULL,
AvailabilityZone = NULL,
VpcEndpointId = NULL,
VpcEndpointAssociationArn = NULL
)
FirewallArn |
[required] The Amazon Resource Name (ARN) of the firewall. |
FlowOperationId |
[required] A unique identifier for the flow operation. This ID is returned in the responses to start and list commands. You provide to describe commands. |
NextToken |
When you request a list of objects with a |
MaxResults |
The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a |
AvailabilityZone |
The ID of the Availability Zone where the firewall is located. For example, Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation. |
VpcEndpointId |
A unique identifier for the primary endpoint associated with a firewall. |
VpcEndpointAssociationArn |
The Amazon Resource Name (ARN) of a VPC endpoint association. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.