View source: R/networkfirewall_operations.R
| networkfirewall_list_flow_operations | R Documentation |
Returns a list of all flow operations ran in a specific firewall. You can optionally narrow the request scope by specifying the operation type or Availability Zone associated with a firewall's flow operations.
See https://www.paws-r-sdk.com/docs/networkfirewall_list_flow_operations/ for full documentation.
networkfirewall_list_flow_operations(
FirewallArn,
AvailabilityZone = NULL,
VpcEndpointAssociationArn = NULL,
VpcEndpointId = NULL,
FlowOperationType = NULL,
NextToken = NULL,
MaxResults = NULL
)
FirewallArn |
[required] The Amazon Resource Name (ARN) of the firewall. |
AvailabilityZone |
The ID of the Availability Zone where the firewall is located. For example, Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation. |
VpcEndpointAssociationArn |
The Amazon Resource Name (ARN) of a VPC endpoint association. |
VpcEndpointId |
A unique identifier for the primary endpoint associated with a firewall. |
FlowOperationType |
An optional string that defines whether any or all operation types are returned. |
NextToken |
When you request a list of objects with a |
MaxResults |
The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.