View source: R/networkfirewall_operations.R
| networkfirewall_list_proxy_rule_groups | R Documentation |
Retrieves the metadata for the proxy rule groups that you have defined. Depending on your setting for max results and the number of proxy rule groups, a single call might not return the full list.
See https://www.paws-r-sdk.com/docs/networkfirewall_list_proxy_rule_groups/ for full documentation.
networkfirewall_list_proxy_rule_groups(NextToken = NULL, MaxResults = NULL)
NextToken |
When you request a list of objects with a |
MaxResults |
The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.