View source: R/networkfirewall_operations.R
| networkfirewall_list_vpc_endpoint_associations | R Documentation |
Retrieves the metadata for the VPC endpoint associations that you have defined. If you specify a fireawll, this returns only the endpoint associations for that firewall.
See https://www.paws-r-sdk.com/docs/networkfirewall_list_vpc_endpoint_associations/ for full documentation.
networkfirewall_list_vpc_endpoint_associations(
NextToken = NULL,
MaxResults = NULL,
FirewallArn = NULL
)
NextToken |
When you request a list of objects with a |
MaxResults |
The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a |
FirewallArn |
The Amazon Resource Name (ARN) of the firewall. If you don't specify this, Network Firewall retrieves all VPC endpoint associations that you have defined. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.