networkfirewall_rejec_netwo_firew_trans_gatew_attac: Rejects a transit gateway attachment request for Network...

networkfirewall_reject_network_firewall_transit_gateway_attachmentR Documentation

Rejects a transit gateway attachment request for Network Firewall

Description

Rejects a transit gateway attachment request for Network Firewall. When you reject the attachment request, Network Firewall cancels the creation of routing components between the transit gateway and firewall endpoints.

See https://www.paws-r-sdk.com/docs/networkfirewall_reject_network_firewall_transit_gateway_attachment/ for full documentation.

Usage

networkfirewall_reject_network_firewall_transit_gateway_attachment(
  TransitGatewayAttachmentId
)

Arguments

TransitGatewayAttachmentId

[required] Required. The unique identifier of the transit gateway attachment to reject. This ID is returned in the response when creating a transit gateway-attached firewall.


paws.networking documentation built on Oct. 8, 2026, 1:14 a.m.