View source: R/networkfirewall_operations.R
| networkfirewall_start_flow_capture | R Documentation |
Begins capturing the flows in a firewall, according to the filters you define. Captures are similar, but not identical to snapshots. Capture operations provide visibility into flows that are not closed and are tracked by a firewall's flow table. Unlike snapshots, captures are a time-boxed view.
See https://www.paws-r-sdk.com/docs/networkfirewall_start_flow_capture/ for full documentation.
networkfirewall_start_flow_capture(
FirewallArn,
AvailabilityZone = NULL,
VpcEndpointAssociationArn = NULL,
VpcEndpointId = NULL,
MinimumFlowAgeInSeconds = NULL,
FlowFilters
)
FirewallArn |
[required] The Amazon Resource Name (ARN) of the firewall. |
AvailabilityZone |
The ID of the Availability Zone where the firewall is located. For example, Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation. |
VpcEndpointAssociationArn |
The Amazon Resource Name (ARN) of a VPC endpoint association. |
VpcEndpointId |
A unique identifier for the primary endpoint associated with a firewall. |
MinimumFlowAgeInSeconds |
The reqested We recommend setting this value to at least 1 minute (60 seconds) to reduce chance of capturing flows that are not yet established. |
FlowFilters |
[required] Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.