View source: R/networkfirewall_operations.R
| networkfirewall_start_flow_flush | R Documentation |
Begins the flushing of traffic from the firewall, according to the filters you define. When the operation starts, impacted flows are temporarily marked as timed out before the Suricata engine prunes, or flushes, the flows from the firewall table.
See https://www.paws-r-sdk.com/docs/networkfirewall_start_flow_flush/ for full documentation.
networkfirewall_start_flow_flush(
FirewallArn,
AvailabilityZone = NULL,
VpcEndpointAssociationArn = NULL,
VpcEndpointId = NULL,
MinimumFlowAgeInSeconds = NULL,
FlowFilters
)
FirewallArn |
[required] The Amazon Resource Name (ARN) of the firewall. |
AvailabilityZone |
The ID of the Availability Zone where the firewall is located. For example, Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation. |
VpcEndpointAssociationArn |
The Amazon Resource Name (ARN) of a VPC endpoint association. |
VpcEndpointId |
A unique identifier for the primary endpoint associated with a firewall. |
MinimumFlowAgeInSeconds |
The reqested |
FlowFilters |
[required] Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.