View source: R/networkfirewall_operations.R
| networkfirewall_update_container_association | R Documentation |
Updates the monitoring configurations and description of a container association. You can't change the container type after creation. Provide an update token to enable optimistic concurrency control.
See https://www.paws-r-sdk.com/docs/networkfirewall_update_container_association/ for full documentation.
networkfirewall_update_container_association(
ContainerAssociationName = NULL,
ContainerAssociationArn = NULL,
Description = NULL,
Type,
ContainerMonitoringConfigurations,
Tags = NULL,
UpdateToken
)
ContainerAssociationName |
The descriptive name of the container association. You must specify the ARN or the name, and you can specify both. |
ContainerAssociationArn |
The Amazon Resource Name (ARN) of the container association. You must specify the ARN or the name, and you can specify both. |
Description |
A description of the container association. When omitted, the existing description remains unchanged. To clear the description, pass an empty string. |
Type |
[required] The container type. This value must match the existing type and can't be changed. Valid values:
|
ContainerMonitoringConfigurations |
[required] The updated monitoring configurations for the container association. Each configuration specifies an Amazon ECS or Amazon EKS cluster to monitor and optional attribute filters. |
Tags |
The key:value pairs to associate with the resource. |
UpdateToken |
[required] A token used for optimistic locking. Network Firewall returns a token to your requests that access the container association. The token marks the state of the container association resource at the time of the request. To make changes to the container association, you provide the token in your request. Network Firewall uses the token to ensure that the container association hasn't changed since you last retrieved it. If it has changed, the operation fails with an |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.