View source: R/networkfirewall_operations.R
| networkfirewall_update_logging_configuration | R Documentation |
Sets the logging configuration for the specified firewall.
See https://www.paws-r-sdk.com/docs/networkfirewall_update_logging_configuration/ for full documentation.
networkfirewall_update_logging_configuration(
FirewallArn = NULL,
FirewallName = NULL,
LoggingConfiguration = NULL,
EnableMonitoringDashboard = NULL
)
FirewallArn |
The Amazon Resource Name (ARN) of the firewall. You must specify the ARN or the name, and you can specify both. |
FirewallName |
The descriptive name of the firewall. You can't change the name of a firewall after you create it. You must specify the ARN or the name, and you can specify both. |
LoggingConfiguration |
Defines how Network Firewall performs logging for a firewall. If you omit this setting, Network Firewall disables logging for the firewall. |
EnableMonitoringDashboard |
A boolean that lets you enable or disable the detailed firewall monitoring dashboard on the firewall. The monitoring dashboard provides comprehensive visibility into your firewall's flow logs and alert logs. After you enable detailed monitoring, you can access these dashboards directly from the Monitoring page of the Network Firewall console. Specify |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.