View source: R/networkmanager_operations.R
| networkmanager_put_attachment_routing_policy_label | R Documentation |
Applies a routing policy label to an attachment for traffic routing decisions.
See https://www.paws-r-sdk.com/docs/networkmanager_put_attachment_routing_policy_label/ for full documentation.
networkmanager_put_attachment_routing_policy_label(
CoreNetworkId,
AttachmentId,
RoutingPolicyLabel,
ClientToken = NULL
)
CoreNetworkId |
[required] The ID of the core network containing the attachment. |
AttachmentId |
[required] The ID of the attachment to apply the routing policy label to. |
RoutingPolicyLabel |
[required] The routing policy label to apply to the attachment. |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.