Learn R Programming

paws.networking (version 0.1.10)

route53_deactivate_key_signing_key: Deactivates a key signing key (KSK) so that it will not be used for signing by DNSSEC

Description

Deactivates a key signing key (KSK) so that it will not be used for signing by DNSSEC. This operation changes the KSK status to INACTIVE.

Usage

route53_deactivate_key_signing_key(HostedZoneId, Name)

Arguments

HostedZoneId

[required] A unique string used to identify a hosted zone.

Name

[required] An alphanumeric string used to identify a key signing key (KSK).

Request syntax

svc$deactivate_key_signing_key(
  HostedZoneId = "string",
  Name = "string"
)