View source: R/route53_operations.R
| route53_update_hosted_zone_features | R Documentation |
Updates the features configuration for a hosted zone. This operation allows you to enable or disable specific features for your hosted zone, such as accelerated recovery.
See https://www.paws-r-sdk.com/docs/route53_update_hosted_zone_features/ for full documentation.
route53_update_hosted_zone_features(
HostedZoneId,
EnableAcceleratedRecovery = NULL
)
HostedZoneId |
[required] The ID of the hosted zone for which you want to update features. This is the unique identifier for your hosted zone. |
EnableAcceleratedRecovery |
Specifies whether to enable accelerated recovery for the hosted zone. Set to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.