For operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain, this operation returns information about whether the registrant contact has responded.
See https://paws-r.github.io/docs/route53domains/get_contact_reachability_status.html for full documentation.
route53domains_get_contact_reachability_status(domainName = NULL)The name of the domain for which you want to know whether the registrant contact has confirmed that the email address is valid.