Lists the following prices for either all the TLDs supported by Route 53, or the specified TLD:
See https://www.paws-r-sdk.com/docs/route53domains_list_prices/ for full documentation.
route53domains_list_prices(Tld = NULL, Marker = NULL, MaxItems = NULL)The TLD for which you want to receive the pricing information. For
example. .net.
If a Tld value is not provided, a list of prices for all TLDs
supported by Route 53 is returned.
For an initial request for a list of prices, omit this element. If the
number of prices that are not yet complete is greater than the value
that you specified for MaxItems, you can use Marker to return
additional prices. Get the value of NextPageMarker from the previous
response, and submit another request that includes the value of
NextPageMarker in the Marker element.
Used only for all TLDs. If you specify a TLD, don't specify a Marker.
Number of Prices to be returned.
Used only for all TLDs. If you specify a TLD, don't specify a
MaxItems.