View source: R/route53resolver_operations.R
| route53resolver_create_resolver_rule | R Documentation |
For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.
See https://www.paws-r-sdk.com/docs/route53resolver_create_resolver_rule/ for full documentation.
route53resolver_create_resolver_rule(
CreatorRequestId,
Name = NULL,
RuleType,
DomainName = NULL,
TargetIps = NULL,
ResolverEndpointId = NULL,
Tags = NULL,
DelegationRecord = NULL
)
CreatorRequestId |
[required] A unique string that identifies the request and that allows failed requests to be retried without the risk of running the operation twice. |
Name |
A friendly name that lets you easily find a rule in the Resolver dashboard in the Route 53 console. The name can be up to 64 characters long and can contain letters (a-z, A-Z), numbers (0-9), hyphens (-), underscores (_), and spaces. The name cannot consist of only numbers. |
RuleType |
[required] When you want to forward DNS queries for specified domain name to resolvers on your network, specify When you have a forwarding rule to forward DNS queries for a domain to your network and you want Resolver to process queries for a subdomain of that domain, specify For example, to forward DNS queries for example.com to resolvers on your network, you create a rule and specify Currently, only Resolver can create rules that have a value of |
DomainName |
DNS queries for this domain name are forwarded to the IP addresses that you specify in |
TargetIps |
The IPs that you want Resolver to forward DNS queries to. You can specify either Ipv4 or Ipv6 addresses but not both in the same rule. Separate IP addresses with a space.
when creating a DELEGATE rule, you must not provide the |
ResolverEndpointId |
The ID of the outbound Resolver endpoint that you want to use to route DNS queries to the IP addresses that you specify in |
Tags |
A list of the tag keys and values that you want to associate with the endpoint. |
DelegationRecord |
DNS queries with the delegation records that match this domain name are forwarded to the resolvers on your network. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.