Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/route53resolver_list_outpost_resolvers/ for full documentation.
route53resolver_list_outpost_resolvers(
OutpostArn = NULL,
MaxResults = NULL,
NextToken = NULL
)The Amazon Resource Name (ARN) of the Outpost.
The maximum number of Resolvers on the Outpost that you want to return
in the response to a ListOutpostResolver request. If you don't specify
a value for MaxResults, the request returns up to 100 Resolvers.
For the first ListOutpostResolver request, omit this value.