Adds one or more tags to a specified resource.
route53resolver_tag_resource(ResourceArn, Tags)[required] The Amazon Resource Name (ARN) for the resource that you want to add
tags to. To get the ARN for a resource, use the applicable Get or
List command:
GetResolverEndpoint
GetResolverRule
GetResolverRuleAssociation
ListResolverEndpoints
ListResolverRuleAssociations
ListResolverRules
[required] The tags that you want to add to the specified resource.
svc$tag_resource(
ResourceArn = "string",
Tags = list(
list(
Key = "string",
Value = "string"
)
)
)