View source: R/servicediscovery_operations.R
| servicediscovery_create_service | R Documentation |
Creates a service. This action defines the configuration for the following entities:
See https://www.paws-r-sdk.com/docs/servicediscovery_create_service/ for full documentation.
servicediscovery_create_service(
Name,
NamespaceId = NULL,
CreatorRequestId = NULL,
Description = NULL,
DnsConfig = NULL,
HealthCheckConfig = NULL,
HealthCheckCustomConfig = NULL,
Tags = NULL,
Type = NULL
)
Name |
[required] The name that you want to assign to the service. Do not include sensitive information in the name if the namespace is discoverable by public DNS queries. If you want Cloud Map to create an
When you register an instance, Cloud Map creates an
For services that are accessible by DNS queries, you can't create multiple services with names that differ only by case (such as EXAMPLE and example). Otherwise, these services have the same DNS name and can't be distinguished. However, if you use a namespace that's only accessible by API calls, then you can create services that with names that differ only by case. |
NamespaceId |
The ID or Amazon Resource Name (ARN) of the namespace that you want to use to create the service. For namespaces shared with your Amazon Web Services account, specify the namespace ARN. For more information about shared namespaces, see Cross-account Cloud Map namespace sharing in the Cloud Map Developer Guide. |
CreatorRequestId |
A unique string that identifies the request and that allows failed |
Description |
A description for the service. |
DnsConfig |
A complex type that contains information about the Amazon Route 53 records that you want Cloud Map to create when you register an instance. |
HealthCheckConfig |
Public DNS and HTTP namespaces only. A complex type that contains settings for an optional Route 53 health check. If you specify settings for a health check, Cloud Map associates the health check with all the Route 53 DNS records that you specify in If you specify a health check configuration, you can specify either For information about the charges for health checks, see Cloud Map Pricing. |
HealthCheckCustomConfig |
A complex type that contains information about an optional custom health check. If you specify a health check configuration, you can specify either You can't add, update, or delete a |
Tags |
The tags to add to the service. Each tag consists of a key and an optional value that you define. Tags keys can be up to 128 characters in length, and tag values can be up to 256 characters in length. |
Type |
If present, specifies that the service instances are only discoverable using the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.