Deletes the Amazon Route 53 DNS records and health check, if any, that Cloud Map created for the specified instance.
See https://paws-r.github.io/docs/servicediscovery/deregister_instance.html for full documentation.
servicediscovery_deregister_instance(ServiceId, InstanceId)[required] The ID of the service that the instance is associated with.
[required] The value that you specified for Id in the
register_instance request.