Learn R Programming

paws.networking (version 0.1.9)

servicediscovery_discover_instances: Discovers registered instances for a specified namespace and service

Description

Discovers registered instances for a specified namespace and service. You can use DiscoverInstances to discover instances for any type of namespace. For public and private DNS namespaces, you can also use DNS queries to discover instances.

Usage

servicediscovery_discover_instances(NamespaceName, ServiceName,
  MaxResults, QueryParameters, HealthStatus)

Arguments

NamespaceName

[required] The name of the namespace that you specified when you registered the instance.

ServiceName

[required] The name of the service that you specified when you registered the instance.

MaxResults

The maximum number of instances that you want AWS Cloud Map to return in the response to a DiscoverInstances request. If you don\'t specify a value for MaxResults, AWS Cloud Map returns up to 100 instances.

QueryParameters

A string map that contains attributes with values that you can use to filter instances by any custom attribute that you specified when you registered the instance. Only instances that match all the specified key/value pairs will be returned.

HealthStatus

The health status of the instances that you want to discover.

Request syntax

svc$discover_instances(
  NamespaceName = "string",
  ServiceName = "string",
  MaxResults = 123,
  QueryParameters = list(
    "string"
  ),
  HealthStatus = "HEALTHY"|"UNHEALTHY"|"ALL"
)

Examples

Run this code
# NOT RUN {
# Example: Discover registered instances
svc$discover_instances(
  HealthStatus = "ALL",
  MaxResults = 10L,
  NamespaceName = "example.com",
  ServiceName = "myservice"
)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab