View source: R/servicediscovery_operations.R
| servicediscovery_list_instances | R Documentation |
Lists summary information about the instances that you registered by using a specified service.
See https://www.paws-r-sdk.com/docs/servicediscovery_list_instances/ for full documentation.
servicediscovery_list_instances(ServiceId, NextToken = NULL, MaxResults = NULL)
ServiceId |
[required] The ID or Amazon Resource Name (ARN) of the service that you want to list instances for. For services created in a shared namespace, specify the service ARN. For more information about shared namespaces, see Cross-account Cloud Map namespace sharing in the Cloud Map Developer Guide. |
NextToken |
For the first If more than |
MaxResults |
The maximum number of instances that you want Cloud Map to return in the response to a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.