Learn R Programming

paws.networking (version 0.7.0)

vpclattice_deregister_targets: Deregisters the specified targets from the specified target group

Description

Deregisters the specified targets from the specified target group.

See https://www.paws-r-sdk.com/docs/vpclattice_deregister_targets/ for full documentation.

Usage

vpclattice_deregister_targets(targetGroupIdentifier, targets)

Arguments

targetGroupIdentifier

[required] The ID or Amazon Resource Name (ARN) of the target group.

targets

[required] The targets to deregister.