View source: R/vpclattice_operations.R
| vpclattice_start_domain_verification | R Documentation |
Starts the domain verification process for a custom domain name.
See https://www.paws-r-sdk.com/docs/vpclattice_start_domain_verification/ for full documentation.
vpclattice_start_domain_verification(
clientToken = NULL,
domainName,
tags = NULL
)
clientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token and parameters, the retry succeeds without performing any actions. If the parameters aren't identical, the retry fails. |
domainName |
[required] The domain name to verify ownership for. |
tags |
The tags for the domain verification. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.