View source: R/apigatewayv2_operations.R
| apigatewayv2_list_product_rest_endpoint_pages | R Documentation |
Lists the product REST endpoint pages of a portal product.
See https://www.paws-r-sdk.com/docs/apigatewayv2_list_product_rest_endpoint_pages/ for full documentation.
apigatewayv2_list_product_rest_endpoint_pages(
MaxResults = NULL,
NextToken = NULL,
PortalProductId,
ResourceOwnerAccountId = NULL
)
MaxResults |
The maximum number of elements to be returned for this resource. |
NextToken |
The next page of elements from this collection. Not valid for the last element of the collection. |
PortalProductId |
[required] The portal product identifier. |
ResourceOwnerAccountId |
The account ID of the resource owner of the portal product. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.