View source: R/apigatewayv2_operations.R
| apigatewayv2_list_routing_rules | R Documentation |
Lists routing rules.
See https://www.paws-r-sdk.com/docs/apigatewayv2_list_routing_rules/ for full documentation.
apigatewayv2_list_routing_rules(
DomainName,
DomainNameId = NULL,
MaxResults = NULL,
NextToken = NULL
)
DomainName |
[required] The domain name. |
DomainNameId |
The domain name ID. |
MaxResults |
The maximum number of elements to be returned for this resource. |
NextToken |
The next page of elements from this collection. Not valid for the last element of the collection. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.