View source: R/cloudfront_operations.R
| cloudfront_get_distribution_tenant_by_domain | R Documentation |
Gets information about a distribution tenant by the associated domain.
See https://www.paws-r-sdk.com/docs/cloudfront_get_distribution_tenant_by_domain/ for full documentation.
cloudfront_get_distribution_tenant_by_domain(Domain)
Domain |
[required] A domain name associated with the target distribution tenant. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.