View source: R/cloudfront_operations.R
| cloudfront_list_connection_groups | R Documentation |
Lists the connection groups in your Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/cloudfront_list_connection_groups/ for full documentation.
cloudfront_list_connection_groups(
AssociationFilter = NULL,
Marker = NULL,
MaxItems = NULL
)
AssociationFilter |
Filter by associated Anycast IP list ID. |
Marker |
The marker for the next set of connection groups to retrieve. |
MaxItems |
The maximum number of connection groups to return. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.