View source: R/cloudfront_operations.R
| cloudfront_list_domain_conflicts | R Documentation |
We recommend that you use the list_domain_conflicts API operation to check for domain conflicts, as it supports both standard distributions and distribution tenants. list_conflicting_aliases performs similar checks but only supports standard distributions.
See https://www.paws-r-sdk.com/docs/cloudfront_list_domain_conflicts/ for full documentation.
cloudfront_list_domain_conflicts(
Domain,
DomainControlValidationResource,
MaxItems = NULL,
Marker = NULL
)
Domain |
[required] The domain to check for conflicts. |
DomainControlValidationResource |
[required] The distribution resource identifier. This can be the standard distribution or distribution tenant that has a valid certificate, which covers the domain that you specify. |
MaxItems |
The maximum number of domain conflicts to return. |
Marker |
The marker for the next set of domain conflicts. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.