View source: R/cloudfront_operations.R
| cloudfront_put_resource_policy | R Documentation |
Creates a resource control policy for a given CloudFront resource.
See https://www.paws-r-sdk.com/docs/cloudfront_put_resource_policy/ for full documentation.
cloudfront_put_resource_policy(ResourceArn, PolicyDocument)
ResourceArn |
[required] The Amazon Resource Name (ARN) of the CloudFront resource for which the policy is being created. |
PolicyDocument |
[required] The JSON-formatted resource policy to create. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.