View source: R/directconnect_operations.R
| directconnect_delete_resiliency_group | R Documentation |
Deletes the specified resiliency group. Deletion is asynchronous: the resiliency group transitions through the deleting state before it reaches the deleted state. The response returns the resiliency group so you can observe its current state without a subsequent get_resiliency_group call.
See https://www.paws-r-sdk.com/docs/directconnect_delete_resiliency_group/ for full documentation.
directconnect_delete_resiliency_group(resiliencyGroupId)
resiliencyGroupId |
[required] The ID of the resiliency group. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.