View source: R/directconnect_operations.R
| directconnect_list_resiliency_groups | R Documentation |
Lists the resiliency groups owned by your Amazon Web Services account in the current Amazon Web Services Region.
See https://www.paws-r-sdk.com/docs/directconnect_list_resiliency_groups/ for full documentation.
directconnect_list_resiliency_groups(maxResults = NULL, nextToken = NULL)
maxResults |
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned If |
nextToken |
The token for the next page of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.