View source: R/directconnect_operations.R
| directconnect_update_connections_billing_mode | R Documentation |
Updates the billing mode for the specified Direct Connect connections. You can update the billing mode for up to 200 connections in a single request.
See https://www.paws-r-sdk.com/docs/directconnect_update_connections_billing_mode/ for full documentation.
directconnect_update_connections_billing_mode(connectionIds, billingMode)
connectionIds |
[required] The IDs of the connections to update. You can specify from 1 to 200 connections. |
billingMode |
[required] The billing mode to apply to the specified connections. The valid values are |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.