View source: R/networkfirewall_operations.R
| networkfirewall_describe_flow_operation | R Documentation |
Returns key information about a specific flow operation.
See https://www.paws-r-sdk.com/docs/networkfirewall_describe_flow_operation/ for full documentation.
networkfirewall_describe_flow_operation(
FirewallArn,
AvailabilityZone = NULL,
VpcEndpointAssociationArn = NULL,
VpcEndpointId = NULL,
FlowOperationId
)
FirewallArn |
[required] The Amazon Resource Name (ARN) of the firewall. |
AvailabilityZone |
The ID of the Availability Zone where the firewall is located. For example, Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation. |
VpcEndpointAssociationArn |
The Amazon Resource Name (ARN) of a VPC endpoint association. |
VpcEndpointId |
A unique identifier for the primary endpoint associated with a firewall. |
FlowOperationId |
[required] A unique identifier for the flow operation. This ID is returned in the responses to start and list commands. You provide to describe commands. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.