| networkfirewall_reject_network_firewall_transit_gateway_attachment | R Documentation |
Rejects a transit gateway attachment request for Network Firewall. When you reject the attachment request, Network Firewall cancels the creation of routing components between the transit gateway and firewall endpoints.
See https://www.paws-r-sdk.com/docs/networkfirewall_reject_network_firewall_transit_gateway_attachment/ for full documentation.
networkfirewall_reject_network_firewall_transit_gateway_attachment(
TransitGatewayAttachmentId
)
TransitGatewayAttachmentId |
[required] Required. The unique identifier of the transit gateway attachment to reject. This ID is returned in the response when creating a transit gateway-attached firewall. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.