route53_activate_key_signing_key: Activates a key signing key (KSK) so that it can be used for signing by
DNSSEC
Description
Activates a key signing key (KSK) so that it can be used for signing by
DNSSEC. This operation changes the KSK status to ACTIVE.
Usage
route53_activate_key_signing_key(HostedZoneId, Name)
Arguments
HostedZoneId
[required] A unique string used to identify a hosted zone.
Name
[required] An alphanumeric string used to identify a key signing key (KSK).
Request syntax
svc$activate_key_signing_key(
HostedZoneId = "string",
Name = "string"
)