Deactivates a key signing key (KSK) so that it will not be used for
signing by DNSSEC. This operation changes the KSK status to INACTIVE.
route53_deactivate_key_signing_key(HostedZoneId, Name)[required] A unique string used to identify a hosted zone.
[required] An alphanumeric string used to identify a key signing key (KSK).
svc$deactivate_key_signing_key( HostedZoneId = "string", Name = "string" )